---
title: Configuration reference
eleventyNavigation:
  key: ⚙️ Configuration reference
  parent: Reference guides
  order: 0
---
## Configuration file

Below is a sample borgmatic configuration file including all available options
for the [most recent version of
borgmatic](https://projects.torsion.org/borgmatic-collective/borgmatic/releases).
This file is also [available for
download](https://torsion.org/borgmatic/docs/reference/config.yaml).

If you're using an older version of borgmatic, some of these options may not
work, and you should instead [generate a sample configuration file specific to
your borgmatic
version](https://torsion.org/borgmatic/docs/how-to/set-up-backups/#configuration).

```yaml
{% include borgmatic/config.yaml %}
```
